@@ -13,18 +13,18 @@
 #' @seealso \code{\link[sensiPhy]{clade_phylm}} 
 #' @details For 'x' from clade_phylm or clade_phyglm:
 #' 
-#' Graph 1: The original scatterplot \eqn{y = a + bx} (with the 
-#' full dataset) and a comparison between the regression lines of the full model
-#' and the model without the selected clade (set by \code{clade}). For further
+#' \strong{Graph 1:} The original scatterplot \eqn{y = a + bx} (with the 
+#' full dataset) and a comparison between the regression lines of the full dataset
+#' and the rerun without the selected clade (set by \code{clade}). For further
 #' details about this method, see \code{\link[sensiPhy]{clade_phylm}}.
 #' 
 #' Species from the selected clade are represented in red (removed species), black
 #' solid line represents the regression with the full model and red dashed line represents
 #' the regression of the model without the species from the selected clade.
-#' To check the available clades to plot, see \code{x$clade.model.estimates$clade} 
+#' To check the available clades to plot, see \code{x$sensi.estimates$clade} 
 #' in the object returned from \code{clade_phylm} or \code{clade_phyglm}. 
 #' 
-#' Graph 2: Distribution of the simulated slopes (Null distribution
+#' \strong{Graph 2:} Distribution of the simulated slopes (Null distribution
 #' for a given clade sample size).
 #' The red dashed line represents the estimated slope for the reduced model 
 #' (without the focal clade) and the black line represents the slope for the 
@@ -35,7 +35,7 @@
 #' @export
 
 sensi_plot.sensiClade <- function(x, clade = NULL, ...){
-    yy <- NULL; slope <- NULL
+    yy <- NULL; estimate <- NULL
     # start:
     full.data <- x$data
     mappx <- x$formula[[3]]
@@ -43,7 +43,7 @@ sensi_plot.sensiClade <- function(x, clade = NULL, ...){
     vars <- all.vars(x$formula)
     clade.col <- x$clade.col
     
-    clades.names <- x$clade.model.estimates$clade
+    clades.names <- x$sensi.estimates$clade
     if (is.null(clade) == T){
         clade <- clades.names[1]
         warning("Clade argument was not defined. Plotting results for clade: ",
@@ -54,23 +54,23 @@ sensi_plot.sensiClade <- function(x, clade = NULL, ...){
     if (length(clade.n) == 0) stop(paste(clade,"is not a valid clade name"))
     
     ### Organizing values:
-    result <- x$clade.model.estimates
+    result <- x$sensi.estimates
     intercept.0 <-  as.numeric(x$full.model.estimates$coef[1])
-    slope.0     <-  as.numeric(x$full.model.estimates$coef[2])
+    estimate.0     <-  as.numeric(x$full.model.estimates$coef[2])
 
-    inter <- c(x$clade.model.estimates$intercept[clade.n ],
+    inter <- c(x$sensi.estimates$intercept[clade.n ],
                intercept.0)
-    slo <-  c(x$clade.model.estimates$slope[clade.n ],
-              slope.0)
+    slo <-  c(x$sensi.estimates$estimate[clade.n ],
+              estimate.0)
     model <- NULL
-    estimates <- data.frame(inter,slo, model=c("Without clade", "Full model"))
+    estimates <- data.frame(inter,slo, model=c("Without clade", "Full data"))
     
     xf <- model.frame(formula = x$formula, data = full.data)[,2]
     yf <- plogis(estimates[2,1] + estimates[2,2] * xf)
     yw <- plogis(estimates[1,1] + estimates[1,2] * xf)
     plot_data <- data.frame("xf" = c(xf,xf),
                             "yy" = c(yw, yf),
-                            model = rep(c("Without clade","Full model"),
+                            model = rep(c("Without clade","Full data"),
                                         each = length(yf)))
                             
     match.y <- which(full.data[, clade.col] == clade)
@@ -85,9 +85,9 @@ sensi_plot.sensiClade <- function(x, clade = NULL, ...){
         
         scale_shape_manual(name = "", values = c("Removed species" = 16))+
         guides(shape = guide_legend(override.aes = list(linetype = 0)))+
-        scale_linetype_manual(name = "Model", values = c("Full model" = "solid",
+        scale_linetype_manual(name = "Model", values = c("Full data" = "solid",
                                                     "Without clade" = "dashed"))+
-        scale_color_manual(name = "Model", values = c("Full model" = "black",
+        scale_color_manual(name = "Model", values = c("Full data" = "black",
                                                     "Without clade" = "red"))+
         theme(axis.text = element_text(size = 12),
               axis.title = element_text(size = 12),
@@ -99,22 +99,22 @@ sensi_plot.sensiClade <- function(x, clade = NULL, ...){
     
     ### Permuation Test plot:
     nd <- x$null.dist
-    ces <- x$clade.model.estimates
+    ces <- x$sensi.estimates
     
     nes <- nd[nd$clade == clade, ]
-    slob <- ces[ces$clade == clade ,]$slope
+    slob <- ces[ces$clade == clade ,]$estimate
     slfu <- x$full.model.estimates$coef[[2]]
     
     ### P.value permutation test:
     p.values <- summary(x)[[1]]
     P <- p.values[p.values$clade.removed == clade, ]$Pval.randomization
   
-    g2 <- ggplot2::ggplot(nes ,aes(x=slope))+
+    g2 <- ggplot2::ggplot(nes ,aes(x=estimate))+
       geom_histogram(fill="yellow",colour="black", size=.2,
                      alpha = .3) +
       geom_vline(xintercept = slob, color="red",linetype=2,size=.7)+
       geom_vline(xintercept = slfu, color="black",linetype=1,size=.7)+
-      xlab(paste("Simulated slopes | N.species = ", 
+      xlab(paste("Simulated estimates | N.species = ", 
                  ces[ces$clade==clade, ]$N.species, "| N.sim = ", 
                  nrow(nes))) +
       ylab("Frequency")+
